/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

package fr.greyc.pantheon.thunder.controller;

import java.awt.Image;
import java.awt.Toolkit;
import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Locale;
import java.util.Vector;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;
import javax.swing.ImageIcon;
import javax.swing.JOptionPane;

import fr.greyc.pantheon.thunder.main.Main;
import fr.greyc.pantheon.thunder.model.ImageLister;
import fr.greyc.pantheon.thunder.model.Language;
import fr.greyc.pantheon.thunder.model.bookmark.Bookmark;
import fr.greyc.pantheon.thunder.model.bookmark.BookmarkList;
import fr.greyc.pantheon.thunder.model.image.ImageInfo;
import fr.greyc.pantheon.thunder.model.image.PandoreThumbnailDecoder;
import fr.greyc.pantheon.thunder.model.image.Thumbnail;
import fr.greyc.pantheon.thunder.model.image.ThumbnailImage;
import fr.greyc.pantheon.thunder.view.ThunderView;
import fr.greyc.pantheon.thunder.view.dialogs.LoadingBox;
import fr.greyc.pantheon.thunder.view.imagesform.ImageCanvas;
import fr.greyc.pantheon.thunder.view.imagesform.ImageFrame;

/**
 * The main class that supports the application.
 *  
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07
 * @author Rgis CLOUARD - 2009-10-06
 */
public class Thunder {
    private static Thunder _instance;
    private ThunderView _root;
    private BookmarkList _bookmarklist;
    private String _currentLanguage;

    /** List of supported languages. */
    public static HashMap<String, Locale> SUPPORTED_LOCALES;

    /**
     * Creates a new viewer.
     * Selects the preferred language, builds the bookmarks and
     * then launches the interface.
     */
    private Thunder() {
    	SUPPORTED_LOCALES = initLocale();
        _currentLanguage = new Language().getLanguage();
        _bookmarklist = new BookmarkList();
        _root = new ThunderView(this, SUPPORTED_LOCALES.get(_currentLanguage));
    }

    /**
     * Implement the Singleton Design Pattern.
     * @return the unique instance of the class.
     */
    public synchronized static Thunder get_instance() {
        if (_instance != null) {
            return _instance;
        } else {
            _instance = new Thunder();
            return _instance;
        }
    }

    /**
     * Permet d'ajouter un bookmark  la liste de bookmarks.
     * @param name le nom du marque page
     * @param path le chemin du dossier
     */
    public void addBookmark(String name, String path) {
        _bookmarklist.addBookmark(new Bookmark(name, path));
    }

    /**
     * Permet d'afficher les informations d'une imgPath dans l'interface graphique.
     * @param info
     */
    public void displayInfo(ImageInfo info) {
        _root.displayInfo(info);
    }

    /**
     * Permet d'afficher une imgPath dans une JFrame diffrente de la thunderView.
     * @param thumbnail l'imgPath taille relle en question
     */
    public void displayRealImage(ThumbnailImage thumbnail) {
        new ImageFrame(thumbnail);
    }

    /**
     * Permet de retourner la liste de bookmarks.
     * @return La rfrence vers la liste de marque-pages.
     */
    public BookmarkList getBookmarkList() {
        return _bookmarklist;
    }

    /**
     * Permet de supprimer la rfrence vers la liste de marque-pages, et d'en
     * affecter une nouvelle.
     * @return La rfrence vers la liste de marque-pages.
     */
    public void setBookmarkList(BookmarkList list) {
        _bookmarklist = list;
    }

    /**
     * Permet de sauvegarder les marque-pages sur le disque de l'utilisateur.
     */
    public void saveBookmarksOnDisk() {
//        System.out.println(_bookmarklist.toString());
        if (!_bookmarklist.saveBookmarksOnDisk()) {
            JOptionPane.showMessageDialog(_root, "Sauvegarde des marque-pages choue.\n" + "Vrifiez que vous avez droit d'criture sur le rpertoire" + Main.CONFIG_FOLDER, "Erreur : Sauvegarde des marque-pages impossible", JOptionPane.ERROR_MESSAGE);
        } else {
            JOptionPane.showMessageDialog(_root, "Sauvegarde des marque-pages russie !", "Sauvegarde russie !", JOptionPane.INFORMATION_MESSAGE);
        }

    }

    /**
     * Permet de positionner et d'afficher l'interface graphique.
     */
    public void showGui() {
        _root.setLocationRelativeTo(null);
        _root.setVisible(true);
    }

    /**
     * Permet de charger dans la fenetre les images contenues dans un repertoire.
     * On cree ici des objets de type Thumbnail.
     * @param dir_path Le chemin dans le disque du repertoire o se trouvent les images
     * @return un vecteur contenant tous les thumbnails  afficher
     */
    public Vector<ThumbnailImage> loadImages(String dir_path) {
        final File[] list = new ImageLister(new File(dir_path)).listImages();
        LoadingBox lb = new LoadingBox(list.length);

        Vector<ThumbnailImage> v = new Vector<ThumbnailImage>();
        int counter = 1;
        for (File f : list) {
            v.add(createImage(f));
            lb.update(counter++);
        }

        lb.dispose();
        return v;
    }

    /**
     * Configures the list of recognized languages.
     * @return a hastable with all languages.
     */
    private static HashMap<String, Locale> initLocale( ) {
        HashMap<String, Locale> h = new HashMap<String, Locale>();
        try {
            JarFile theJar = new JarFile(System.getProperty("user.dir") + "//" + System.getProperty("java.class.path"));
            Enumeration<JarEntry> theFiles = theJar.entries();
            while (theFiles.hasMoreElements()) {
                JarEntry entry = theFiles.nextElement();
                String name = entry.getName();
                if (!entry.isDirectory() && name.endsWith("properties")) {
                    /* Just get the name of the language files.*/
                	final String filenameprefix = "message_";
                	int i = name.indexOf(filenameprefix);
                	String s = name.substring(i);
                	String language=s.substring(filenameprefix.length(), filenameprefix.length()+"fr".length());
                	String country=s.substring(filenameprefix.length()+"fr_".length(), filenameprefix.length()+"fr_".length()+"FR".length());
                    h.put(language, new Locale(language,country));
                }
            }
        } catch (IOException ex) {
//           Logger.getLogger(Main.class.getName()).log(Level.SEVERE, null, ex);
            h.put("en", new Locale("en","US")); // By default
            h.put("fr", new Locale("fr","FR"));	 // By default
        }
        return h;
    }

    /**
     * Methode permettant de changer de language. Reconstruit la fenetre Thunderview. (?)
     */
    public void changeLanguage() {
        _currentLanguage = new Language().changeLanguage();
        _root.setVisible(false);
        _root =  null; /* On detruit la fenetre */
        _root = new ThunderView(this, SUPPORTED_LOCALES.get(_currentLanguage));
        showGui();
    }

    /**
     * Permet de crer un objet de type Thumbnail.
     * On cree une image reduite soit en servant du decoder PandoreThumbnailDecoder
     * s'il s'agit d'une image pandore, soit par la methode classique s'il s'agit d'un
     * autre type d'image.
     * @param imgPath Le chemin absolu de l'image.
     * @return un objet de type Thumbnail
     */
    private Thumbnail createImage(File imgPath) {
        /* On recupere le chemin de l'imgPath */
        String path = imgPath.getAbsolutePath();

        ImageIcon imageIcon = null;
        Image img;

        ImageInfo info = new ImageInfo();
        info.set_size(imgPath.length());
        info.set_name(imgPath.getName());
        info.set_path(path);

        /* Creation de l'image */
        try {
            imageIcon = new ImageIcon(imgPath.toURI().toURL());
            /* Calculer les informations de l'image : taille, poids en octets et nom */
            info.set_width(imageIcon.getIconWidth());
            info.set_height(imageIcon.getIconHeight());

            if (imageIcon.getIconWidth() < 0) { // May be a Pandore image ??

                PandoreThumbnailDecoder pan = new PandoreThumbnailDecoder();
                pan.readImage(path);
                img =
                        Toolkit.getDefaultToolkit().createImage(pan);
                imageIcon =
                        new ImageIcon(img);

                info.set_width(imageIcon.getIconWidth());
                info.set_height(imageIcon.getIconHeight());
                if (imageIcon.getIconWidth() < 0) {
                    /* maybe a 3D image */
                    return null;
                }
            }

            img = imageIcon.getImage();

            if (imageIcon.getIconWidth() > ImageCanvas.DIM_IMAGE) {
                img = img.getScaledInstance(ImageCanvas.DIM_IMAGE, -1, Image.SCALE_FAST);
            } else if (imageIcon.getIconHeight() > ImageCanvas.DIM_IMAGE) {
                img = img.getScaledInstance(-1, ImageCanvas.DIM_IMAGE, Image.SCALE_FAST);
            }

            return new Thumbnail(img, imgPath, info);

        } catch (MalformedURLException e) {
            /* Not an image */
            return new Thumbnail(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"warning.png")).getImage(), imgPath, null);
        }
    }
}