/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

package fr.greyc.pantheon.thunder.model;

import java.io.File;
import java.io.FilenameFilter;

/**
 * Classe qui,  partir d'un objet File reprsentant un dossier,
 * liste toutes les images d'un certains type, et renvoie un vecteur
 * de String contenant les chemins absolus des images dans le dossier.
 * 
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07
 */
public class ImageLister {

	private File _file;
	private File[] _list;

	public ImageLister(File f) {
		_file = f;
		_list = _file.listFiles(new ImagePanFilter());
	}

	/**
	 * Renvoie la liste des images sous la forme d'un tableau d'objets File.
	 * @return la liste des images contenues dans le fichier paramtre de la classe.
	 */
	public File[] listImages() {
		return _list;
	}

	/**
	 * Renvoie le nombre d'images d'un fichier
	 * @return le nombre d'image contenu dans le fichier paramtre de la classe.
	 */
	public int getNbImages() {
		return _list.length;
	}

	/**
	 * Classe permettant de filtrer les images par types.
	 * Images acceptes : jpg, gif, png et pan
	 */
	private class ImagePanFilter implements FilenameFilter {

		@Override
		public boolean accept(File dir, String name) {
			if (name.endsWith("pan") || name.endsWith("jpg") || name.endsWith("JPG") ||
					name.endsWith("jpeg") || name.endsWith("gif") || name.endsWith("png") || name.endsWith("JPEG")) {
				return true;
			}
			return false;
		}
	}
}
