/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

/**
 * Classe permettant de reprsenter un marque page.
 * 
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07
 *
 */
package fr.greyc.pantheon.thunder.model.bookmark;

import java.io.File;

import fr.greyc.pantheon.thunder.model.ImageLister;

public class Bookmark implements IBookmark{

	private String _name;
	private File _path;

	/**
	 * Constructeur
	 */
	public Bookmark(String nom, String chemin){
		_name = nom;
        File f;
		if( ! (f = new File(chemin)).isDirectory()){
			System.err.println("La cration du bookmark "+nom+" / "+chemin+ " a echou.");
		}
        else {
            _path = f;
        }
	}


	/**
	 * Fonction permettant de recuperer le chemin du bookmark
	 * @return Le chemin du bookmark
	 */
    @Override
	public String getPath() {
		return _path.getPath();
	}

	/**
	 * Fonction permettant de fixer le chemin du bookmark
	 * @param st Le nom du chemin
	 */
    @Override
	public void setPath(File st) {
		this._path = st;
	}

	/**
	 * Fonction permettant de recuperer le nom du bookmark
	 * @return Le nom du bookmark
	 */
    @Override
	public String getName() {
		return this._name;
	}

	/**
	 * Permet de fixer le nom du bookmark
	 * @param st Le nom du bookmark
	 */
    @Override
	public void setName(String st) {
		this._name = st;
	}

	/**
	 * Permet d'afficher le nom du bookmark.
	 */
    @Override
	public String toString() {
		return _name.toString();
	}


	/**
	 * Permet de tester si deux bookmarks sont les memes.
     * On compare seulement les noms des bookmarks
	 * @param b Le bookmark avec lequel on compare
	 * @return Un booleen
	 */
    @Override
    public boolean equals(Object b) {
        if (b == null){
            return false;
        }
        return _name.equalsIgnoreCase(((Bookmark)b).getName());
    }


    /**
     * Permet d'avoir le nombre d'images contenues dans un bookmark
     * @return Le nombre d'images contenues dans le marque-page.
     */
    @Override
    public int getNbImages() {
        return (new ImageLister(_path).getNbImages());
    }
}
