/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

package fr.greyc.pantheon.thunder.model.bookmark;

import java.util.Vector;

/**
 * Classe permettant de reprsenter une liste de bookmaks.
 * 
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07
 */
public class BookmarkList {

    /* La liste de bookmarks */
    private Vector<IBookmark> _list;

    /* Permet de restaurer et sauvegarder les marque-pages sur le disque-dur de
     * l'utilisateur.  */
    private BookmarkReaderWriter _saver;

    /**
     * Constructeur
     */
    public BookmarkList() {
        _saver = new BookmarkReaderWriter();
        /* On charge les bookmarks sauvegards sur le disque de l'utilisateur */
        _list = _saver.readOnDisk();
    }

    /**
     * Permet d'ajouter un bookmark dans la liste
     * @param b Le bookmark a ajoute
     */
    public void addBookmark(IBookmark b) {
        _list.add(b);
    }

    /**
     * Permet d'effacer le bookmark specifie en parametre
     * @param b Le bookmark a efface
     */
    public void removeBookmark(IBookmark b) {
        _list.remove(b);
    }

    /**
     * Permet de retourner le bookmark dont le numero
     * est specifie en parametre
     * @param i Le numero de bookmark a retourne
     * @return Le bookmark souhaite
     */
    public IBookmark getBookmark(int i) {
        return _list.get(i);
    }

    /**
     * Permet de retourner le bookmark dont le nom est
     * spcifi en paramtre.
     * @return Le bookmark souhait, null si pas trouv
     */
    public IBookmark getBookmark(String name) {
        for (IBookmark ib : _list) {
            if (ib.getName().equals(name)) {
                return ib;
            }
        }
        return null;
    }

    /**
     * Permet d'afficher la liste des bookmarks
     * @return La reprsentation sous forme de chaine de caractres de la liste
     * de marque-pages.
     */
    @Override
    public String toString() {
        String str = "";
        for (IBookmark ib : _list) {
            str += ib.toString() + "\n";
        }
        return str;
    }

    /**
     * Permet de compter le nombre de bookmark dans la liste.
     * @return Le nombre de marque-pages.
     */
    public int getNbBookmarks() {
        return _list.size();
    }

    /**
     * Permet de sauvegarder les marque-pages de l'utilisateur sur son disque-dur.
     */
    public boolean saveBookmarksOnDisk() {
        return _saver.writeOnDisk(_list);
    }
}
