/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

package fr.greyc.pantheon.thunder.model.bookmark;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;
import java.util.Vector;
import java.util.logging.Level;
import java.util.logging.Logger;

import fr.greyc.pantheon.thunder.main.Main;
import fr.greyc.pantheon.thunder.model.Language;

/**
 * Classe abstraite permettant de spcifier un comportement pour une lecture et une
 * criture dans un fichier de configuration de bookmarks.
 * 
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07
 */
public class BookmarkReaderWriter {
	/* The configuration file name. */
	public static final String FILE_PATH = Main.CONFIG_FOLDER + "//bookmark.cfg";

	/**
	 * Permet de lire le fichier de configuration des bookmarks
	 * prsent sur le disque de l'utilisateur.
	 * S'il n'est pas prsent, renvoit un vecteur de bookmark vide.
	 * @return une liste de bookmark, nulle si le fichier n'existe pas.
	 */
	public Vector<IBookmark> readOnDisk() {
		File configurationFile = new File(FILE_PATH);
		Vector<IBookmark> liste = new Vector<IBookmark>();
		/* si le fichier n'existe pas */
		if (!configurationFile.exists()) {
			return liste;
		}

		BufferedReader input;
		String line = "", bookmark = "", bookmarkPath = "";
		StringTokenizer st;
		try {
			input = new BufferedReader(new FileReader(configurationFile));
			/* lecture du fichier ligne par ligne */
			while ((line = input.readLine()) != null) {
				st = new StringTokenizer(line, "#");
				bookmark = st.nextToken();
				bookmarkPath = st.nextToken();
				/* on ajoute un nouveau bookmark */
				liste.add(new Bookmark(bookmark, bookmarkPath));
			}
			input.close();

		} catch (FileNotFoundException ex) {
			System.err.println("Erreur d'ouverture du fichier " + configurationFile.getAbsolutePath());
			Logger.getLogger(Language.class.getName()).log(Level.SEVERE, null, ex);
			return liste;

		} catch (IOException ex) {
			System.err.println("Erreur de lecture dans le fichier " + configurationFile.getAbsolutePath());
			Logger.getLogger(Language.class.getName()).log(Level.SEVERE, null, ex);
			return liste;

		} catch (NoSuchElementException ex) {
			return liste;
		}
		return liste;
	}

	/**
	 * Permet de sauvegarder la liste de marque-pages sur le disque.
	 * @param list la liste de marque-pages.
	 * @return vrai si l'criture  russi, faux sinon.
	 */
	public boolean writeOnDisk(Vector<IBookmark> list) {
		boolean success = true;
	
		File configurationFile = new File(FILE_PATH);
		/* si le fichier n'existe pas, on le cre*/
		if (!configurationFile.exists()) {
			try {
				configurationFile.createNewFile();
			} catch (IOException ex) {
				System.err.println("Erreur de cration du fichier de configuration " + configurationFile.getAbsolutePath());
				Logger.getLogger(BookmarkReaderWriter.class.getName()).log(Level.SEVERE, null, ex);
				return !success;
			}
		}

		try {
			PrintWriter pt = new PrintWriter(configurationFile);
			for (IBookmark ib : list) {
				pt.write(ib.getName() + "#" + ib.getPath() + "\n");
			}
			pt.close();
		} catch (FileNotFoundException ex) {
			System.err.println("Erreur d'ouverture du fichier " + configurationFile.getAbsolutePath());
			Logger.getLogger(BookmarkReaderWriter.class.getName()).log(Level.SEVERE, null, ex);
			return !success;
		}

		return success;
	}
}
