/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

package fr.greyc.pantheon.thunder.model.image;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JMenu;
import javax.swing.JPopupMenu;

import fr.greyc.pantheon.thunder.controller.Thunder;
import fr.greyc.pantheon.thunder.main.Main;
import fr.greyc.pantheon.thunder.model.bookmark.BookmarkList;
import fr.greyc.pantheon.thunder.view.popup.DeleteStrategy;
import fr.greyc.pantheon.thunder.view.popup.PopupItem;
import fr.greyc.pantheon.thunder.view.popup.SendToBookmarkStrategy;
/**
 * Classe permettant de grer l'affichage des miniatures.
 * Dans tous les cas de clic sur ce bouton : fais apparaitre les informations de l'image.
 * Deux clics sur ce bouton : fais apparaitre l'image dans une jframe spare en taille relle
 * (ou pas si l'image est trop grande).
 * 
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07
 */
public class ImageButton extends JButton implements ActionListener {

	private ImageInfo _imageInfo;
	private ThumbnailImage _thumbnail;
	/* Le nombre de millisecondes entre chaque clic pour faire un double clic */
	private long _mouseDoubleClickThreshold = 300L;
	/* Le temps du clic prcdent */
	private long _previousClicTime = 0;
	private JPopupMenu _menuPopup;

	public ImageButton(ThumbnailImage ti) {
		_thumbnail = ti;
		ImageIcon imageIcon = new ImageIcon(ti.displayThumbnail());
		this.setIcon(imageIcon);
		_imageInfo = ti.get_info();
		addActionListener(this);
		this.setContentAreaFilled(false);
		this.addPopupMenu();
	}

	/**
	 * Constructeur par defaut.
	 * On creer une image icon de base (genre toto.png), et des infos bidons.
	 * On ne fait rien en cas de clic sur cette image.
	 */
	public ImageButton() {
		ImageIcon imageIcon = new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"warning.png"));
		this.setIcon(imageIcon);
		this.setContentAreaFilled(false);
	}

	/**
	 * Permet de grer le clic et le double clic sur un imageButton.
	 * Un clic : on affiche les infos de l'images.
	 * deux clics : on envoit la miniature au controleur pour qu'il l'affiche
	 * dans une jframe spare en taille relle.
	 * @param arg0
	 */
	@Override
	public void actionPerformed(ActionEvent arg0) {
		long eventTime = arg0.getWhen();
		long timeDiff = eventTime - _previousClicTime;
		/* Pour viter d'avoir une diffrence ngative due aux entiers signs de Java */
		if (timeDiff < 0) {
			timeDiff = -timeDiff;
		}
		if (_mouseDoubleClickThreshold > timeDiff) {
			/* double clic */
			Thunder.get_instance().displayRealImage(_thumbnail);
			_previousClicTime = 0;
		} else {
			/* simple clic */
			_previousClicTime = eventTime;
			Thunder.get_instance().displayInfo(_imageInfo);
		}
	}

	/**
	 * Permet de crer un menu contextuel
	 * quand on clique avec le bouton droit de la souris
	 * sur l'image miniature.
	 */
	private void addPopupMenu() {
		_menuPopup = new JPopupMenu();

		/* Pour supprimer une image */
		PopupItem popupSupprimer = new PopupItem("Supprimer", new DeleteStrategy(_imageInfo));
		_menuPopup.add(popupSupprimer);

		/* Pour copier une image dans un marque-page */
		JMenu popupSend = new JMenu("Copier dans un marque-pages");
		BookmarkList list = Thunder.get_instance().getBookmarkList();
		for (int i=0; i<list.getNbBookmarks(); i++){
			popupSend.add(
					new PopupItem(list.getBookmark(i).getName(),
							new SendToBookmarkStrategy(_imageInfo, list.getBookmark(i))));
		}
		/* and so on... */
		_menuPopup.add(popupSend);

		MouseListener popupListener = new PopupListener(_menuPopup);
		this.addMouseListener(popupListener);
	}

	/**
	 * Sous-classe permettant d'ouvrir le menu contextuel des images.
	 */
	private class PopupListener extends MouseAdapter {

		private JPopupMenu _popup;

		PopupListener(JPopupMenu popupMenu) {
			_popup = popupMenu;
		}

		@Override
		public void mousePressed(MouseEvent e) {
			maybeShowPopup(e);
		}

		@Override
		public void mouseReleased(MouseEvent e) {
			maybeShowPopup(e);
		}

		/**
		 * Permet d'ouvrir le menu contextuel si et seulement si
		 * l'utilisateur clique droit sur le bouton.
		 * @param e L'evenement de souris.
		 */
		private void maybeShowPopup(MouseEvent e) {
			if (e.isPopupTrigger()) {
				_popup.show(e.getComponent(),
						e.getX(), e.getY());
			}
		}
	}


}
