/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

package fr.greyc.pantheon.thunder.model.image;

import java.awt.Image;
import java.io.File;

/**
 * Un objet Thumbnail reprsente la miniature de l'image.
 * On ralise galement le pattern proxy : si on demande au Thumbnail d'afficher l'image entire,
 * il cre un objet RealImage et lui demande de s'afficher.
 * 
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07
 */
public class Thumbnail implements ThumbnailImage {

    private File _filename;
    private Image _icon;
    private DisplayableImage _realImage;
    private ImageInfo _info;


    /**
     * Permet de creer un objet Thumbnail
     * @param ic
     * @param path
     */
    public Thumbnail(Image ic, File path, ImageInfo i) {
        _icon = ic;
        _filename = path;
        _info = i;
    }

    /**
     * Permet d'afficher l'image entire.
     * On cre un objet RealImage auquel on demande de s'afficher.
     * @return l'image du thumbnail
     */
    @Override
    public Image getRealImage() {
        if (_realImage == null) {
            _realImage = new RealImage(_filename);
        }
        return _realImage.displayRealImage();
    }

    /**
     * Permet d'afficher la miniature.
     * @return L'image miniature  afficher.
     */
    @Override
    public Image displayThumbnail() {
        return _icon;
    }

    /**
     * Permet d'acceder aux informations de l'image taille relle.
     * @return Une instance de la classe imageInfo
     */
    @Override
    public ImageInfo get_info() {
        return _info;
    }


   
}
