/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */
/*
 * ArboPanel.java
 *
 * Created on 14 dc. 2008, 17:47:42
 */
package fr.greyc.pantheon.thunder.view;

import java.awt.Component;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.io.File;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeCellRenderer;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.TreePath;
import javax.swing.tree.TreeSelectionModel;

import fr.greyc.pantheon.thunder.main.Main;
import fr.greyc.pantheon.thunder.model.ImageLister;

/**
 * The folders explorer.
 * 
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07
 * @author Rgis CLOUARD - 2009-10-06
 */
public class Explorer extends javax.swing.JPanel implements TreeSelectionListener {
	private DefaultMutableTreeNode _top;
	private DefaultTreeModel _treeModel;

	/**
	 * Builds the explorer with the specified primary folder.
	 * @param foldername the current folder name.
	 */
	public Explorer( String foldername ) {
		File folder = new File(foldername);
		File parent = folder.getParentFile();
		if (folder.isDirectory()) {
			DefaultMutableTreeNode top = new FileNodeDefault(folder);
			_top = new FileNodeTop(parent);
			_treeModel = new DefaultTreeModel(top);
			initComponents();
			_tree.getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);
			_tree.setCellRenderer(new TreeRenderer());
			init_nodes(top);
		}

		_tree.setToggleClickCount(0);
		/*
		 * On cree un nouveau MouseListener pour detecter le simple clic et le
		 * double clic de souris sur les noeuds de l'arbre
		 */
		MouseListener ml = new MouseAdapter() {

			/**
			 * Permet de lister les images contenues dans un repertoire donn.
			 * On se sert de la classe ImageLister dans le package model.
			 * @param filepath
			 * @return
			 */
			@Override
			public void mousePressed(MouseEvent e) {
				int selRow = _tree.getRowForLocation(e.getX(), e.getY());
				if (selRow != -1) {
					if (e.getClickCount() == 2) {
						FileNode node = (FileNode) _tree.getLastSelectedPathComponent();
						if (node == null) {
							return;
						}
//						System.out.println(node.getNodeName() + "   " + node.getNodePath());
						ThunderView.loadImages(node.getNodePath());
					}
				}
			}
		};

		_tree.addMouseListener(ml);
		_tree.addTreeSelectionListener(this);

	}

	/**
	 * Enlve tous les noeuds  l'exception de la racine.
	 */
	private void clear() {
		_top.removeAllChildren();
		_treeModel.reload();
	}

	/**
	 * Permet de renvoyer l'objet contenu dans le noeud slectionn de l'arbre.
	 * @return Un objet File.
	 */
	public File getSelectedFile() {
		FileNode node = (FileNode) _tree.getLastSelectedPathComponent();
		if (node == null) {
			System.err.println("Pas de noeud selectionn !!");
			return null;
		}

		return node.getFile();
	}

	/**
	 * Permet d'initialiser le panel  partir d'un nom de fichier.
	 * @param path
	 */
	public void initAll(String path) {
		File fi = new File(path);
		if (fi.isDirectory()) {
			clear();
			DefaultMutableTreeNode top = new FileNodeDefault(fi);
			_top = new FileNodeDefault(fi.getParentFile());
			_treeModel = new DefaultTreeModel(top);
			_tree.setModel(_treeModel);
			init_nodes(top);
		}
	}

	/**
	 * This method is called from within the constructor to
	 * initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is
	 * always regenerated by the Form Editor.
	 */
	@SuppressWarnings("unchecked")
	private void initComponents() {//GEN-BEGIN:initComponents
		jScrollPane1 = new JScrollPane();
		_tree = new JTree(_treeModel);
		jScrollPane1.setViewportView(_tree);
		javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
		this.setLayout(layout);
		layout.setHorizontalGroup(
				layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 249, Short.MAX_VALUE)
		);
		layout.setVerticalGroup(
				layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
				.addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 184, Short.MAX_VALUE)
		);
	}//GEN-END:initComponents

	// Variables declaration - do not modify//GEN-BEGIN:variables
	private JTree _tree;
	private javax.swing.JScrollPane jScrollPane1;
	// End of variables declaration//GEN-END:variables

	/**
	 * Add subfolders into the tree of folders.
	 * @param root the tree.
	 */
	private void init_nodes( DefaultMutableTreeNode root ) {
		FileNode category = null;
		FileNode rac = (FileNode) root;
		File[] list;
		/* On liste le repertoire */
		list = rac.getFile().listFiles();
		ImageLister il;

		for (int i = 0; i < list.length; i++) {
			/* Si le fichier courant est un dossier */
			if (list[i].isDirectory()) {
				if (list[i].canExecute() && list[i].canRead()) {
					/*
					 * Si on a droit de lecture et execution sur le repertoire,
					 * on le liste pour voir s'il contient des images.
					 */
					il = new ImageLister(list[i]);
					if (il.getNbImages() != 0) {
						category = new FileNodeImage(list[i]);
					} else {
						category = new FileNodeDefault(list[i]);
					}
					root.add(category);
				}
			}
		}
		if (root.getChildCount() != 0) {
			ouvrir(root);
		}
	}

	/**
	 * Permet d'etendre un noeud
	 *
	 * @param node
	 *            Le noeud en question
	 */
	private void ouvrir(DefaultMutableTreeNode node) {
		if (node == null) {
			return;
		}

		if (node.isLeaf()) {
			node = (DefaultMutableTreeNode) node.getParent();
		}
		_tree.expandPath(new TreePath(node.getPath()));
	}

	/**
	 * Spcifie le comportement de l'arbre en cas de clic sur un noeud.
	 * @param e
	 */
	@Override
	public void valueChanged(TreeSelectionEvent e) {
		DefaultMutableTreeNode node = (DefaultMutableTreeNode) _tree.getLastSelectedPathComponent();
		if (node == null) {
			return;
		}
		/* Si le noeud n'a pas encore de fils, alors on les cherche */
		if (node.getChildCount() == 0) {
			init_nodes(node);
		} else {
			return;
		}
	}

	/**
	 * Classe MyRenderer
	 *
	 * @author Julian
	 *
	 *         Permet de specifier le visuel de l'arborescence.
	 */
	private class TreeRenderer extends DefaultTreeCellRenderer {

		private Icon _iconNormal = new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"folder_16.png"));
		private Icon _iconImg = new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"folder_full_16.png"));

		@Override
		public Component getTreeCellRendererComponent(JTree tree, Object value,
				boolean sel, boolean expanded, boolean leaf, int row,
				boolean hasFocus) {

			super.getTreeCellRendererComponent(tree, value, sel, expanded,
					leaf, row, hasFocus);

			FileNode node = (FileNode) value;

			if (node == null) {
				return this;
			}

			if (node instanceof FileNodeDefault) {
				setIcon(_iconNormal);
			} else {
				setIcon(_iconImg);
			}
			return this;

		}
	}
}