/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

package fr.greyc.pantheon.thunder.view;

import java.io.File;
import javax.swing.Icon;
import javax.swing.tree.DefaultMutableTreeNode;

/**
 * A node in the explorer tree.
 * 
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07

 */
public abstract class FileNode extends DefaultMutableTreeNode {

	protected File _file;
	protected Icon _icon;

	/**
	 *  
	 * @param f
	 */
	public FileNode( File f ) {
		super();
		this.setUserObject(new FileNodeInfo(f.getAbsolutePath(), f.getName()));
		_file = f;
	}

	/**
	 * Permet de rcuprer le file du noeud.
	 */
	public File getFile(){
		return _file;
	}

	/**
	 * Permet de rcuprer le path du noeud.
	 * @return Le chemin absolu du noeud de l'arbre.
	 */
	public String getNodePath(){
		FileNodeInfo f = (FileNodeInfo) getUserObject();
		return f.get_path();
	}

	/**
	 * Permet de rcuprer le nom du noeud
	 * @return Le nom du rpertoire correspondant  ce noeud.
	 */
	public String getNodeName(){
		FileNodeInfo f = (FileNodeInfo) getUserObject();
		return f.get_name();
	}


	/**
	 * Classe FileNodeInfo
	 *
	 * @author Julian
	 *
	 *         Permet de representer des noeuds de l'arborescence.
	 */
	protected class FileNodeInfo {

		private String _path;
		private String _name;

		public FileNodeInfo(String path, String name) {
			_path = path;
			_name = name;
		}

		/**
		 * Retourne le chemin absolu.
		 * @return le chemin absolu du noeud de l'arbre
		 */
		public String get_path() {
			return _path;
		}

		/**
		 * Retourne le nom du noeud (le nom du dossier en general)
		 * @return le nom du dossier du noeud de l'arbre
		 */
		public String get_name() {
			return _name;
		}

		@Override
		public String toString() {
			return _name;
		}
	}
}
