/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

/*
 * ThunderView.java
 *
 * Created on 14 dc. 2008, 17:47:15
 */
package fr.greyc.pantheon.thunder.view;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;
import java.util.Locale;

import javax.swing.GroupLayout;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBoxMenuItem;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing. JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JSplitPane;
import javax.swing. JToolBar;
import javax.swing.KeyStroke;
import javax.swing.LayoutStyle;
import javax.swing.SwingConstants;
import javax.swing.WindowConstants;
import javax.swing.JToolBar.Separator;

import fr.greyc.pantheon.thunder.controller.Thunder;
import fr.greyc.pantheon.thunder.main.Main;
import fr.greyc.pantheon.thunder.model.Translator;
import fr.greyc.pantheon.thunder.model.bookmark.BookmarkList;
import fr.greyc.pantheon.thunder.model.image.ImageInfo;
import fr.greyc.pantheon.thunder.view.dialogs.AboutBox;
import fr.greyc.pantheon.thunder.view.dialogs.ManageBookmarksBox;
import fr.greyc.pantheon.thunder.view.imagesform.ImagesPanel;

/**
 * The window manager.
 * s
 * @author Julian CHENARD - 2009-04-07 
 * @author Jrmy GAUTIER - 2009-04-07
 */
public class ThunderView extends JFrame {
	private Thunder _viewer;
	private AboutBox _aboutBox;
	private ManageBookmarksBox _manageBookmarksBox;
	private boolean _autoSave = false;
	private static String _currentDir = Main.CONFIG_FOLDER;

	public ThunderView(Thunder v, Locale locale) {
		super("-- T H U N D E R --");
		_viewer = v;
		Main.currentLocale = locale;
		initComponents();
		addWindowListener(new WindowAdapter() {

			@Override
			public void windowClosing(WindowEvent we) {
				if (_autoSave) {
					saveBookmarkOnDisk(null);
				}
				System.exit(0);
			}
		});

		initSplitPane();
		initIcon();
		initBookmarks();
	}

	/**
	 * Permet d'afficher les informations d'une image via le controleur.
	 * @param info les infos  afficher
	 */
	public void displayInfo(ImageInfo info) {
		_infoPanel.update(info);
	}

	/**
	 * Permet de changer les images du panel droit.
	 * La methode est statique car elle peut être lance de n'importe quelle objet.
	 * @param dir_path Le chemin absolu du dossier que l'on veut lister.
	 */
	public static void loadImages(final String dir_path) {
		ThunderView._currentDir = dir_path;
		Thread t = new Thread() {

			@Override
			public void run() {
				_imgPanel.loadImages(Thunder.get_instance().loadImages(dir_path));
			}
		};
		t.start();
	}

	/**
	 * Permet de charger les marque-pages existants dans la fenetre.
	 */
	public void initBookmarks() {
		JMenuItem j;
		_openBookmarkMenu.removeAll();
		BookmarkList blist = _viewer.getBookmarkList();
		int nb = blist.getNbBookmarks();
		for (int i = 0; i < nb; i++) {
			j = new JMenuItem();
			j.setText(blist.getBookmark(i).getName());
			j.addActionListener(new ActionListener() {

				@Override
				public void actionPerformed(ActionEvent e) {
					/* Quand on clique sur un bookmark, ça ouvre le dossier correspondant
					 * a la base de l'arborescence. */
					JMenuItem source = (JMenuItem) e.getSource();
					openBookmark(source.getText());
				}
			});
			_openBookmarkMenu.add(j);
		}
	}

	/**
	 * Permet d'ouvrir un bookmark.
	 * @param name Le nom du bookmark.
	 */
	private void openBookmark(String name) {
		BookmarkList blist = _viewer.getBookmarkList();
		_explorer.initAll(blist.getBookmark(name).getPath());
	}

	/**
	 * Permet de spcifier une icone pour Thunder (en haut  gauche de la fenêtre)
	 */
	private void initIcon() {
		setIconImage(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"icon_16.png")).getImage());
	}

	/**
	 * Permet de fixer la position du sparateur du split pane au depart.
	 */
	private void initSplitPane() {
		_splitPane.setDividerLocation(250);
	}

	/** This method is called from within the constructor to
	 * initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is
	 * always regenerated by the Form Editor.
	 */
	@SuppressWarnings("unchecked")
	private void initComponents() {//GEN-BEGIN:initComponents
		_panelInfos = new JPanel();
		_infoPanel = new InfoPanel();
		_toolBar = new JToolBar();
		_btnOpen = new JButton(Translator.displayValue(Main.currentLocale, "ouvrirRepBt"),
				new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"open_32.png")));
		Separator jSeparator1 = new JToolBar.Separator();
		_btnMarquer = new JButton(Translator.displayValue(Main.currentLocale, "ajouterMPBt"), new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"markdir_32.png")));
		_btnOrganiser = new JButton(Translator.displayValue(Main.currentLocale, "organiserMPBt"), new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"managebookmarks_32.png")));
		Separator jSeparator2 = new Separator();
		_btnRefresh = new JButton(Translator.displayValue(Main.currentLocale, "refreshBt"), new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"refresh_32.png")));
		Separator jSeparator6 = new JToolBar.Separator();
		_btnQuitter = new JButton(Translator.displayValue(Main.currentLocale, "quitterBt"), new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"logout_32.png")));
		_splitPane = new JSplitPane();
		_explorer = new Explorer(System.getProperty("user.dir"));
		_scrollPane = new JScrollPane();
		_imgPanel = new ImagesPanel();
		_menuBar = new JMenuBar();
		_menuFichier = new JMenu(Translator.displayValue(Main.currentLocale, "fichier"));
		_ouvrir = new JMenuItem(Translator.displayValue(Main.currentLocale, "ouvrirRep"));
		jSeparator3 = new JSeparator();
		_quit = new JMenuItem(Translator.displayValue(Main.currentLocale, "quitter"));
		_menuBookmarks = new JMenu(Translator.displayValue(Main.currentLocale, "marquepage"));
		_markThisInBookmark = new JMenuItem(Translator.displayValue(Main.currentLocale, "marquerRep"));
		_addDirectory = new JMenuItem(Translator.displayValue(Main.currentLocale, "ajouterMP"));
		jSeparator4 = new JSeparator();
		_openBookmarkMenu = new JMenu(Translator.displayValue(Main.currentLocale, "ouvrirMP"));
		jSeparator5 = new JSeparator();
		_organizeBookmark = new JMenuItem(Translator.displayValue(Main.currentLocale, "gererMP"));
		_saveBookmark = new JMenuItem(Translator.displayValue(Main.currentLocale, "sauvegarderMP"));
		_menuConfiguration = new JMenu(Translator.displayValue(Main.currentLocale, "configuration"));
		_changeLanguageMenu = new JMenuItem(Translator.displayValue(Main.currentLocale, "changerlangue"));
		_saveAutoItem = new JCheckBoxMenuItem(Translator.displayValue(Main.currentLocale, "sauvegardeauto"));
		_menuAide = new JMenu(Translator.displayValue(Main.currentLocale, "aide"));
		_apropos = new JMenuItem(Translator.displayValue(Main.currentLocale, "apropos"));

		setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);

		GroupLayout _panelInfosLayout = new GroupLayout(_panelInfos);
		_panelInfos.setLayout(_panelInfosLayout);
		_panelInfosLayout.setHorizontalGroup(
				_panelInfosLayout.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addGap(0, 1099, Short.MAX_VALUE)
				.addGroup(_panelInfosLayout.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addComponent(_infoPanel, GroupLayout.DEFAULT_SIZE, 1099, Short.MAX_VALUE))
		);
		_panelInfosLayout.setVerticalGroup(
				_panelInfosLayout.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addGap(0, 26, Short.MAX_VALUE)
				.addGroup(_panelInfosLayout.createParallelGroup(GroupLayout.Alignment.LEADING)
						.addComponent(_infoPanel, GroupLayout.DEFAULT_SIZE, 26, Short.MAX_VALUE))
		);

		_toolBar.setFloatable(false);
		_toolBar.setRollover(true);

		_btnOpen.setFocusable(false);
		_btnOpen.setHorizontalTextPosition(SwingConstants.CENTER);
		_btnOpen.setVerticalTextPosition(SwingConstants.BOTTOM);
		_btnOpen.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				btnOpenDir(evt);
			}
		});
		_toolBar.add(_btnOpen);
		_toolBar.add(jSeparator1);

		_btnMarquer.setFocusable(false);
		_btnMarquer.setHorizontalTextPosition(SwingConstants.CENTER);
		_btnMarquer.setVerticalTextPosition(SwingConstants.BOTTOM);
		_btnMarquer.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				btnMarkThisDirectory(evt);
			}
		});
		_toolBar.add(_btnMarquer);

		_btnOrganiser.setFocusable(false);
		_btnOrganiser.setHorizontalTextPosition(SwingConstants.CENTER);
		_btnOrganiser.setVerticalTextPosition(SwingConstants.BOTTOM);
		_btnOrganiser.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				btnManageBookmark(evt);
			}
		});
		_toolBar.add(_btnOrganiser);
		_toolBar.add(jSeparator2);

		_btnRefresh.setFocusable(false);
		_btnRefresh.setHorizontalTextPosition(SwingConstants.CENTER);
		_btnRefresh.setVerticalTextPosition(SwingConstants.BOTTOM);
		_btnRefresh.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				_btnRefreshActionPerformed(evt);
			}
		});
		_toolBar.add(_btnRefresh);
		_toolBar.add(jSeparator6);

		_btnQuitter.setFocusable(false);
		_btnQuitter.setHorizontalTextPosition(SwingConstants.CENTER);
		_btnQuitter.setVerticalTextPosition(SwingConstants.BOTTOM);
		_btnQuitter.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				btnQuit(evt);
			}
		});
		_toolBar.add(_btnQuitter);

		_splitPane.setLeftComponent(_explorer);

		GroupLayout _imgPanelLayout = new GroupLayout(_imgPanel);
		_imgPanel.setLayout(_imgPanelLayout);
		_imgPanelLayout.setHorizontalGroup(
				_imgPanelLayout.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addGap(0, 1054, Short.MAX_VALUE)
		);
		_imgPanelLayout.setVerticalGroup(
				_imgPanelLayout.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addGap(0, 505, Short.MAX_VALUE)
		);

		_scrollPane.setViewportView(_imgPanel);

		_splitPane.setRightComponent(_scrollPane);

		_ouvrir.setAccelerator(KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_O, java.awt.event.InputEvent.CTRL_MASK));
		_ouvrir.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"open_16.png"))); // NOI18N
		_ouvrir.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				openDir(evt);
			}
		});
		_menuFichier.add(_ouvrir);
		_menuFichier.add(jSeparator3);

		_quit.setAccelerator(KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_Q, java.awt.event.InputEvent.CTRL_MASK));
		_quit.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"logout_16.png"))); // NOI18N
		_quit.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				quit(evt);
			}
		});
		_menuFichier.add(_quit);

		_menuBar.add(_menuFichier);

		_markThisInBookmark.setAccelerator(KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_A, java.awt.event.InputEvent.ALT_MASK));
		_markThisInBookmark.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"markdir_16.png"))); // NOI18N
		_markThisInBookmark.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				markThisDirectory(evt);
			}
		});
		_menuBookmarks.add(_markThisInBookmark);

		_addDirectory.setAccelerator(KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_M, java.awt.event.InputEvent.CTRL_MASK));
		_addDirectory.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"add_16.png"))); // NOI18N
		_addDirectory.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				addExternalDirectoryInBookmarks(evt);
			}
		});
		_menuBookmarks.add(_addDirectory);
		_menuBookmarks.add(jSeparator4);

		_openBookmarkMenu.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"bookmark_16.png"))); // NOI18N
		_menuBookmarks.add(_openBookmarkMenu);
		_menuBookmarks.add(jSeparator5);

		_organizeBookmark.setAccelerator(KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_M, java.awt.event.InputEvent.ALT_MASK | java.awt.event.InputEvent.CTRL_MASK));
		_organizeBookmark.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"managebookmarks_16.png"))); // NOI18N
		_organizeBookmark.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				manageBookmarks(evt);
			}
		});
		_menuBookmarks.add(_organizeBookmark);

		_saveBookmark.setAccelerator(KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_S, java.awt.event.InputEvent.CTRL_MASK));
		_saveBookmark.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"savebookmarks_16.png"))); // NOI18N
		_saveBookmark.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				saveBookmarkOnDisk(evt);
			}
		});
		_menuBookmarks.add(_saveBookmark);

		_menuBar.add(_menuBookmarks);

		_changeLanguageMenu.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"language_16.png"))); // NOI18N
		_changeLanguageMenu.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				_changeLanguageMenuActionPerformed(evt);
			}
		});
		_menuConfiguration.add(_changeLanguageMenu);

		_saveAutoItem.setSelected(false);
		_saveAutoItem.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"save_16.png"))); // NOI18N
		_saveAutoItem.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				_saveAutoItemActionPerformed(evt);
			}
		});
		_menuConfiguration.add(_saveAutoItem);

		_menuBar.add(_menuConfiguration);

		_apropos.setAccelerator(KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_F1, 0));
		_apropos.setIcon(new ImageIcon(getClass().getClassLoader().getResource(Main.iconDir+"help_16.png"))); // NOI18N
		_apropos.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				aboutUs(evt);
			}
		});
		_menuAide.add(_apropos);

		_menuBar.add(_menuAide);

		setJMenuBar(_menuBar);

		GroupLayout layout = new GroupLayout(getContentPane());
		getContentPane().setLayout(layout);
		layout.setHorizontalGroup(
				layout.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addComponent(_panelInfos, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
				.addComponent(_splitPane, GroupLayout.DEFAULT_SIZE, 1099, Short.MAX_VALUE)
				.addComponent(_toolBar, GroupLayout.DEFAULT_SIZE, 1099, Short.MAX_VALUE)
		);
		layout.setVerticalGroup(
				layout.createParallelGroup(GroupLayout.Alignment.LEADING)
				.addGroup(layout.createSequentialGroup()
						.addComponent(_toolBar, GroupLayout.PREFERRED_SIZE, 64, GroupLayout.PREFERRED_SIZE)
						.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
						.addComponent(_splitPane, GroupLayout.DEFAULT_SIZE, 507, Short.MAX_VALUE)
						.addPreferredGap(LayoutStyle.ComponentPlacement.RELATED)
						.addComponent(_panelInfos, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
		);

		pack();
	}//GEN-END:initComponents

	/**
	 * Permet d'ouvrir un rpertoire  la base de l'arborescence.
	 * @param evt l'vnement gnrateur de cette action
	 */
	private void btnOpenDir(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnOpenDir
		openDir(evt);
	}//GEN-LAST:event_btnOpenDir

	/**
	 * Permet d'ouvrir une fenêtre  propos de l'application
	 * @param evt l'vnement gnrateur de cette action
	 */
	private void aboutUs(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_aboutUs
		_aboutBox = new AboutBox();
		_aboutBox.setLocationRelativeTo(this);
		_aboutBox.setVisible(true);
	}//GEN-LAST:event_aboutUs

	/**
	 * Permet d'ouvrir un rpertoire  la base de l'arborescence.
	 * @param evt l'venement gnrateur de cette action.
	 */
	private void openDir(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_openDir
		JFileChooser chooser = new JFileChooser();
		chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
		int returnVal = chooser.showOpenDialog(this);
		if (returnVal == JFileChooser.APPROVE_OPTION) {
			_explorer.initAll(chooser.getSelectedFile().getPath());
		}
	}//GEN-LAST:event_openDir

	/**
	 * Permet de quitter l'application.
	 * @param evt l'venement gnrateur de cette action.
	 */
	private void btnQuit(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnQuit
		quit(evt);
	}//GEN-LAST:event_btnQuit

	/**
	 * Permet de quitter l'application.
	 * @param evt l'venement gnrateur de cette action.
	 */
	private void quit(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_quit
		System.exit(0);
	}//GEN-LAST:event_quit

	/**
	 * Permet de grer ses marque-pages en ouvrant une fenêtre de configuration.
	 * @param evt l'venement gnrateur de cette action.
	 */
	private void btnManageBookmark(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnManageBookmark
		manageBookmarks(evt);
	}//GEN-LAST:event_btnManageBookmark

	/**
	 * Permet d'ajouter un rpertoire en tant que marque-pages.
	 * @param evt l'venement gnrateur de cette action.
	 */
	private void btnMarkThisDirectory(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnMarkThisDirectory
		markThisDirectory(evt);
	}//GEN-LAST:event_btnMarkThisDirectory

	/**
	 * Permet de sauvegarder ses marque-pages sur le disque dur de l'utilisateur
	 * @param evt l'venement gnrateur de cette action.
	 */
	private void saveBookmarkOnDisk(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_saveBookmarkOnDisk
		_viewer.saveBookmarksOnDisk();
	}//GEN-LAST:event_saveBookmarkOnDisk

	/**
	 * Permet d'ajouter un rpertoire en tant que marque-pages.
	 * On ouvre un jfilechooser puis on ajoute le rpertoire slectionn en tant que
	 * marque-pages.
	 * @param evt l'venement gnrateur de cette action.
	 */
	private void addExternalDirectoryInBookmarks(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addExternalDirectoryInBookmarks
		JFileChooser chooser = new JFileChooser();
		chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
		int returnVal = chooser.showOpenDialog(this);
		if (returnVal == JFileChooser.APPROVE_OPTION) {
			File selectedFile = chooser.getSelectedFile();
			_viewer.addBookmark(selectedFile.getName(), selectedFile.getAbsolutePath());
		}
		/* on reload le menu d'ouverture des marque-pages */
		this.initBookmarks();
	}//GEN-LAST:event_addExternalDirectoryInBookmarks

	/**
	 * Permet de grer ses marque-pages en ouvrant une fenêtre de configuration.
	 * @param evt l'venement gnrateur de cette action.
	 */
	private void manageBookmarks(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_manageBookmarks
		_manageBookmarksBox = new ManageBookmarksBox(this, _viewer.getBookmarkList(), Main.currentLocale);
		_manageBookmarksBox.setLocationRelativeTo(this);
		_manageBookmarksBox.setVisible(true);
		/* on reload le menu d'ouverture des marque-pages */
		this.initBookmarks();
	}//GEN-LAST:event_manageBookmarks

	/**
	 * Permet d'ajouter le rpertoire slectionn dans l'arborescence en marque-pages.
	 * @param evt l'venement gnrateur de cette action.
	 */
	private void markThisDirectory(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_markThisDirectory
		File node = _explorer.getSelectedFile();
		if (node == null) {
			JOptionPane.showMessageDialog(this, "Vous devez selectionner un rpertoire dans l'arborescence", "Attention", JOptionPane.INFORMATION_MESSAGE);
			return;
		}
		_viewer.addBookmark(node.getName(), node.getAbsolutePath());
	}//GEN-LAST:event_markThisDirectory

	/**
	 * Permet de changer le langage de Thunder "en live".
	 * @param evt Pas pris en compte ici.
	 */
	private void _changeLanguageMenuActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event__changeLanguageMenuActionPerformed
		_viewer.changeLanguage();
	}//GEN-LAST:event__changeLanguageMenuActionPerformed

	/**
	 * Permet de sauvegarder automatiquement les marque-pages si la check box est
	 * active.
	 * @param evt L'evenement  traiter.
	 */
	private void _saveAutoItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event__saveAutoItemActionPerformed
		JCheckBoxMenuItem checkbox = (JCheckBoxMenuItem) evt.getSource();
		_autoSave = checkbox.isSelected();
	}//GEN-LAST:event__saveAutoItemActionPerformed

	/**
	 * Permet de recharger un dossier aprs sa modification.
	 * @param evt
	 */
	@SuppressWarnings("static-access")
	private void _btnRefreshActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event__btnRefreshActionPerformed
		this.loadImages(_currentDir);
	}//GEN-LAST:event__btnRefreshActionPerformed

	// Variables declaration - do not modify//GEN-BEGIN:variables
	private Explorer _explorer;
	
	private JMenuItem _addDirectory;
	private JMenuItem _apropos;
	private JButton _btnMarquer;
	private JButton _btnOpen;
	private JButton _btnOrganiser;
	private JButton _btnQuitter;
	private JButton _btnRefresh;
	private JMenuItem _changeLanguageMenu;
	public static ImagesPanel _imgPanel;
	private InfoPanel _infoPanel;
	private JMenuItem _markThisInBookmark;
	private JMenu _menuAide;
	private JMenuBar _menuBar;
	private JMenu _menuBookmarks;
	private JMenu _menuConfiguration;
	private JMenu _menuFichier;
	private JMenu _openBookmarkMenu;
	private JMenuItem _organizeBookmark;
	private JMenuItem _ouvrir;
	private JPanel _panelInfos;
	private JMenuItem _quit;
	private JCheckBoxMenuItem _saveAutoItem;
	private JMenuItem _saveBookmark;
	private JScrollPane _scrollPane;
	private JSplitPane _splitPane;
	private JToolBar _toolBar;
	private JSeparator jSeparator3;
	private JSeparator jSeparator4;
	private JSeparator jSeparator5;
	// End of variables declaration//GEN-END:variables
}
