/* -*- c-basic-offset: 3 -*-
 *
 * Copyright (c) GREYC - IMAGE
 *
 * GREYC- IMAGE
 * 6 Boulevard Marchal Juin
 * F-14050 Caen Cedex France
 *
 *
 * This file is part of the PANTHEON Project
 * http://www.greyc.ensicaen.fr/~regis/Pantheon
 *
 *
 * This file is free software and is provided "AS IS" without a warranty
 * of any kind. Redistribution and use of this source code, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * - THE ENTIRE RISK TO THE QUALITY AND PERFORMANCE OF THIS SOFTWARE IS
 *   WITH YOU.
 * - THE GREYC SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *   AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS FILE OR ITS
 *   DERIVATIVES.
 * - THE NAME OF THE GREYC MAY NOT BE USED TO ENDORSE OR PROMOTE PRODUCTS
 *   DERIVED FROM THIS SOFTWARE WITHOUT SPECIFIC PRIOR WRITTEN PERMISSION.
 */

package fr.greyc.pantheon.thunder.view.dialogs;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;
import java.util.Locale;
import java.util.Vector;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JFileChooser;
import javax.swing.JOptionPane;

import fr.greyc.pantheon.thunder.controller.Thunder;
import fr.greyc.pantheon.thunder.model.Translator;
import fr.greyc.pantheon.thunder.model.bookmark.Bookmark;
import fr.greyc.pantheon.thunder.model.bookmark.BookmarkList;
import fr.greyc.pantheon.thunder.model.bookmark.IBookmark;
import fr.greyc.pantheon.thunder.view.ThunderView;

/**
 * Classe permettant de reprsenter une fenetre de gestion des marque-pages.
 * 
 * @author Julian CHENARD - 2009-02-13 
 * @author Jrmy GAUTIER - 2009-02-13
 */
public class ManageBookmarksBox extends javax.swing.JFrame implements ActionListener {
    private BookmarkList _bookmarkList;
    private IBookmark _current;
    private Locale _currentLocale;
    private ThunderView _root;

    /** Creates new ManageBookmarksBox */
    public ManageBookmarksBox() {
        _bookmarkList = new BookmarkList();
        _currentLocale = Locale.FRANCE;
        initComponents();
        initComboBox();
    }

    /** Creates new ManageBookmarksBox */
    public ManageBookmarksBox(ThunderView tv, BookmarkList blist, Locale current) {
        _root = tv;
        _bookmarkList = blist;
        _currentLocale = current;
        initComponents();
        initComboBox();
    }

    /**
     * Permet d'initialiser la liste droulante avec la liste des marque-pages
     * enregistrs.
     */
    private void initComboBox() {
        int size = _bookmarkList.getNbBookmarks();
        Vector<IBookmark> items = new Vector<IBookmark>(size);
        for (int i = 0; i < size; i++) {
            items.add(_bookmarkList.getBookmark(i));
        }
        _combo.setModel(new DefaultComboBoxModel(items));

        /* Ajout de l'actionListener */
        _combo.addActionListener(this);
        if (size <= 0) {
            _current = null;
        } else {
            _current = _bookmarkList.getBookmark(0);
        }
        updateTextFields();
    }

    /**
     * Permet de mettre  jour les champs de textes reprsentant le nom et
     * le dossier du marque-pages.
     * @param e
     */
    @Override
    public void actionPerformed(ActionEvent e) {
        IBookmark bookmark = (IBookmark) _combo.getSelectedItem();
        _current = bookmark;
        updateTextFields();
    }

    /** This method is called from within the constructor to
     * initialize the form.
     */
    @SuppressWarnings("unchecked")
    private void initComponents() {

        _label0 = new javax.swing.JLabel();
        _combo = new javax.swing.JComboBox();
        _label1 = new javax.swing.JLabel();
        _label2 = new javax.swing.JLabel();
        _validButton = new javax.swing.JButton();
        _nameField = new javax.swing.JTextField();
        _pathField = new javax.swing.JTextField();
        _quitButton = new javax.swing.JButton();
        _nameDefaultButton = new javax.swing.JButton();
        _pathDefaultButton = new javax.swing.JButton();
        _parcourirButton = new javax.swing.JButton();
        _supprButton = new javax.swing.JButton();
        javax.swing.JSeparator separator0 = new javax.swing.JSeparator();

        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {

            @Override
            public void windowClosing(WindowEvent we) {
                _quitButtonActionPerformed(null);
            }
        });

        _label0.setText(Translator.displayValue(_currentLocale, "choisirMPachanger"));

        _label1.setText(Translator.displayValue(_currentLocale, "nomMP"));

        _label2.setText(Translator.displayValue(_currentLocale, "dossierMP"));

        _validButton.setText(Translator.displayValue(_currentLocale, "enregistrerMP"));
        _validButton.addActionListener(new java.awt.event.ActionListener() {

            @Override
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                _validButtonActionPerformed(evt);
            }
        });

        _quitButton.setText(Translator.displayValue(_currentLocale, "quitterbox"));
        _quitButton.addActionListener(new java.awt.event.ActionListener() {

            @Override
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                _quitButtonActionPerformed(evt);
            }
        });

        _nameDefaultButton.setText(Translator.displayValue(_currentLocale, "retablir"));
        _nameDefaultButton.addActionListener(new java.awt.event.ActionListener() {

            @Override
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                _nameDefaultButtonActionPerformed(evt);
            }
        });

        _pathDefaultButton.setText(Translator.displayValue(_currentLocale, "retablir"));
        _pathDefaultButton.addActionListener(new java.awt.event.ActionListener() {

            @Override
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                _pathDefaultButtonActionPerformed(evt);
            }
        });

        _parcourirButton.setText(Translator.displayValue(_currentLocale, "parcourir"));
        _parcourirButton.addActionListener(new java.awt.event.ActionListener() {

            @Override
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                _parcourirButtonActionPerformed(evt);
            }
        });

        _supprButton.setText(Translator.displayValue(_currentLocale, "supprimerMP"));
        _supprButton.addActionListener(new java.awt.event.ActionListener() {

            @Override
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                _supprButtonActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
                layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addContainerGap().addComponent(_label0)).addGroup(layout.createSequentialGroup().addContainerGap().addComponent(_label1)).addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup().addGap(35, 35, 35).addComponent(_combo, 0, 333, Short.MAX_VALUE).addGap(18, 18, 18).addComponent(_supprButton)).addGroup(layout.createSequentialGroup().addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addGap(35, 35, 35).addComponent(_nameField, javax.swing.GroupLayout.DEFAULT_SIZE, 341, Short.MAX_VALUE)).addGroup(layout.createSequentialGroup().addContainerGap().addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING).addComponent(_label2).addGroup(layout.createSequentialGroup().addGap(24, 24, 24).addComponent(_pathField, javax.swing.GroupLayout.PREFERRED_SIZE, 251, javax.swing.GroupLayout.PREFERRED_SIZE))).addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED).addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING).addComponent(_validButton, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE).addComponent(_parcourirButton, javax.swing.GroupLayout.DEFAULT_SIZE, 85, Short.MAX_VALUE)))).addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED).addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false).addComponent(_nameDefaultButton, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE).addComponent(_pathDefaultButton, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE).addComponent(_quitButton, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))).addGroup(layout.createSequentialGroup().addContainerGap().addComponent(separator0, javax.swing.GroupLayout.DEFAULT_SIZE, 457, Short.MAX_VALUE))).addContainerGap()));
        layout.setVerticalGroup(
                layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addContainerGap().addComponent(_label0).addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED).addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE).addComponent(_combo, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE).addComponent(_supprButton)).addGap(9, 9, 9).addComponent(separator0, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE).addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED).addComponent(_label1).addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED).addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE).addComponent(_nameField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE).addComponent(_nameDefaultButton)).addGap(18, 18, 18).addComponent(_label2).addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED).addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE).addComponent(_pathField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE).addComponent(_pathDefaultButton).addComponent(_parcourirButton)).addGap(29, 29, 29).addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE).addComponent(_quitButton).addComponent(_validButton)).addContainerGap(17, Short.MAX_VALUE)));

        pack();
    }

    /**
     * Permet de remettre le nom par defaut du marque-pages.
     * @param evt
     */
    private void _nameDefaultButtonActionPerformed(java.awt.event.ActionEvent evt) {
        _nameField.setText(_current.getName());
    }

    /**
     * Permet de supprimer un marque-pages.
     * @param evt
     */
    private void _supprButtonActionPerformed(java.awt.event.ActionEvent evt) {
        IBookmark ib = (IBookmark) _combo.getSelectedItem();
        _bookmarkList.removeBookmark(ib);
//        System.out.println("Marque page "+ib.getPath()+" supprim");
        this.initComboBox();
        /*updateViewerList();*/
    }

    /**
     * Permet de remettre le dossier par defaut du marque-pages.
     * @param evt
     */
    private void _pathDefaultButtonActionPerformed(java.awt.event.ActionEvent evt) {
        _pathField.setText(_current.getPath());
    }

    /**
     * Permet de parcourir le disque dur  la recherche d'un dossier.
     * @param evt
     */
    private void _parcourirButtonActionPerformed(java.awt.event.ActionEvent evt) {
        JFileChooser chooser = new JFileChooser();
        chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
        int returnVal = chooser.showOpenDialog(this);
        if (returnVal == JFileChooser.APPROVE_OPTION) {
            _pathField.setText(chooser.getSelectedFile().getPath());
        }
    }

    /**
     * Permet de quitter la fenetre d'organisation des marque-pages.
     * @param evt Pas pris en compte ici.
     */
    private void _quitButtonActionPerformed(java.awt.event.ActionEvent evt) {
        this.dispose();
    }

    /**
     * Permet d'enregistrer les modifications de l'utilisateur.
     * On verifie galement qu'un nom et un dossier est correctement inscrit.
     * @param evt Pas pris en compte ici.
     */
    private void _validButtonActionPerformed(java.awt.event.ActionEvent evt) {
        String nom,path  = "";
        if ((nom = _nameField.getText()).equals("")) {
            JOptionPane.showMessageDialog(this, "Il faut rentrer un nom pour le marque-pages.");
            return;
        }
        if ((path = _pathField.getText()).equals("")) {
            JOptionPane.showMessageDialog(this, "Il faut rentrer un dossier.");
            return;
        }

        File fpath = new File(path);
        if (!fpath.exists()) {
            JOptionPane.showMessageDialog(this, "Le dossier n'est pas valide.");
            return;
        }

        _bookmarkList.removeBookmark(_current);
        _current = new Bookmark(nom, path);
        _bookmarkList.addBookmark(_current);
        updateViewerList();
    }


    /**
     * Permet de mettre  jour la liste de marque-pages du controleur.
     */
    private void updateViewerList() {
        Thunder.get_instance().setBookmarkList(_bookmarkList);
        _root.initBookmarks();
    }

    /**
     * Permet de mettre  jour les champs de textes nom et dossier du marque-pages.
     */
    private void updateTextFields() {
    	if (_current == null) return;
        _nameField.setText(_current.getName());
        _pathField.setText(_current.getPath());
    }
    
    private javax.swing.JTextField _nameField;
    private javax.swing.JComboBox _combo;
    private javax.swing.JLabel _label0;
    private javax.swing.JLabel _label1;
    private javax.swing.JLabel _label2;
    private javax.swing.JButton _nameDefaultButton;
    private javax.swing.JButton _pathDefaultButton;
    private javax.swing.JTextField _pathField;
    private javax.swing.JButton _quitButton;
    private javax.swing.JButton _validButton;
    private javax.swing.JButton _parcourirButton;
    private javax.swing.JButton _supprButton;
}
